# 💀 skelevision 💀
An implementation of the Log - Skeleton Visualiser in python.

# Installation
For this you can just do:
```shell
pip install skelevision
```

# Basic Usage
NOTE: The following is a short overview on how to use the library. For further information refer to the [official documentation](https://skelevision.github.io/skelevision/).

## The Trace Log Object

## The Log Skeleton Miner
